@@ -40,9 +40,10 @@ impl QueryBuilder for PostgresQueryBuilder {
 
     fn prepare_bin_oper(&self, bin_oper: &BinOper, sql: &mut SqlWriter, collector: &mut dyn FnMut(Value)) {
         match bin_oper {
-            BinOper::Matches => write!(sql, "{}", "@@").unwrap(),
-            BinOper::Contains => write!(sql, "{}", "@>").unwrap(),
-            BinOper::Contained => write!(sql, "{}", "<@").unwrap(),
+            BinOper::Matches => write!(sql, "@@").unwrap(),
+            BinOper::Contains => write!(sql, "@>").unwrap(),
+            BinOper::Contained => write!(sql, "<@").unwrap(),
+            BinOper::Concatenate => write!(sql, "||").unwrap(),
             _ => self.prepare_bin_oper_common(bin_oper, sql, collector),
         }
     }
