@@ -1,8 +1,7 @@
+use sea_query::{tests_cfg::*, *};
+
 mod foreign_key;
 mod index;
-mod online;
 #[allow(deprecated)]
 mod query;
 mod table;
-
-use sea_query_test::*;
